#[repr(C)]pub struct optionstruct {Show 21 fields
pub getcanon: c_int,
pub digraph: boolean,
pub writeautoms: boolean,
pub writemarkers: boolean,
pub defaultptn: boolean,
pub cartesian: boolean,
pub linelength: c_int,
pub outfile: *mut FILE,
pub userrefproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: *mut c_int, arg6: *mut c_int, arg7: *mut set, arg8: *mut c_int, arg9: c_int, arg10: c_int)>,
pub userautomproc: Option<unsafe extern "C" fn(arg1: c_int, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: c_int, arg6: c_int)>,
pub userlevelproc: Option<unsafe extern "C" fn(arg1: *mut c_int, arg2: *mut c_int, arg3: c_int, arg4: *mut c_int, arg5: *mut statsblk, arg6: c_int, arg7: c_int, arg8: c_int, arg9: c_int, arg10: c_int, arg11: c_int)>,
pub usernodeproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: c_int, arg6: c_int, arg7: c_int, arg8: c_int, arg9: c_int)>,
pub usercanonproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut graph, arg4: c_ulong, arg5: c_int, arg6: c_int, arg7: c_int) -> c_int>,
pub invarproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: c_int, arg6: c_int, arg7: *mut c_int, arg8: c_int, arg9: boolean, arg10: c_int, arg11: c_int)>,
pub tc_level: c_int,
pub mininvarlevel: c_int,
pub maxinvarlevel: c_int,
pub invararg: c_int,
pub dispatch: *mut dispatchvec,
pub schreier: boolean,
pub extra_options: *mut c_void,
}Fields
getcanon: c_intdigraph: booleanwriteautoms: booleanwritemarkers: booleandefaultptn: booleancartesian: booleanlinelength: c_intoutfile: *mut FILEuserrefproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: *mut c_int, arg6: *mut c_int, arg7: *mut set, arg8: *mut c_int, arg9: c_int, arg10: c_int)>userautomproc: Option<unsafe extern "C" fn(arg1: c_int, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: c_int, arg6: c_int)>userlevelproc: Option<unsafe extern "C" fn(arg1: *mut c_int, arg2: *mut c_int, arg3: c_int, arg4: *mut c_int, arg5: *mut statsblk, arg6: c_int, arg7: c_int, arg8: c_int, arg9: c_int, arg10: c_int, arg11: c_int)>usernodeproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: c_int, arg6: c_int, arg7: c_int, arg8: c_int, arg9: c_int)>usercanonproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut graph, arg4: c_ulong, arg5: c_int, arg6: c_int, arg7: c_int) -> c_int>invarproc: Option<unsafe extern "C" fn(arg1: *mut graph, arg2: *mut c_int, arg3: *mut c_int, arg4: c_int, arg5: c_int, arg6: c_int, arg7: *mut c_int, arg8: c_int, arg9: boolean, arg10: c_int, arg11: c_int)>tc_level: c_intmininvarlevel: c_intmaxinvarlevel: c_intinvararg: c_intdispatch: *mut dispatchvecschreier: booleanextra_options: *mut c_voidImplementations
Sourceimpl optionstruct
impl optionstruct
Sourcepub fn default_digraph() -> Self
pub fn default_digraph() -> Self
Default options for directed graphs, equivalent to nauty’s DEFAULTOPTIONS_DIGRAPH.
Sourcepub fn default_sparse() -> Self
pub fn default_sparse() -> Self
Default options for undirected sparse graphs, equivalent to nauty’s DEFAULTOPTIONS_SPARSEGRAPH.
Sourcepub fn default_sparse_digraph() -> Self
pub fn default_sparse_digraph() -> Self
Default options for directed sparse graphs, equivalent to nauty’s DEFAULTOPTIONS_SPARSEDIGRAPH.